<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Seo Html Sitemap Hyva Compatibility
 */

namespace Amasty\SeoHtmlSitemapHyva\Helper;

use Amasty\SeoHtmlSitemap\Helper\Renderer as OriginalRenderer;
use Hyva\Theme\Service\CurrentTheme;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Framework\Escaper;

class Renderer extends OriginalRenderer
{
    /**
     * @var CurrentTheme
     */
    private $currentTheme;

    /**
     * @var Escaper
     */
    private $escaper;

    /**
     * @var string
     */
    private $alpineAttrributes = 'x-data=initAmHref ' .
        'x-init=initHref($el.innerHTML) ' .
        'x-on:am-sitemap-search-change.window=onSearchTextChange ' .
        'x-html=html ' .
        'x-bind:class="!isVisible && \'hidden\'"';

    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager,
        CurrentTheme $currentTheme,
        Escaper $escaper
    ) {
        parent::__construct($context, $storeManager);
        $this->currentTheme = $currentTheme;
        $this->escaper = $escaper;
    }

    public function renderTree($collection, $level = 0, $isTree = true)
    {
        if (!$this->currentTheme->isHyva()) {
            return parent::renderTree($collection, $level, $isTree);
        }

        if (self::$_rootId === null) {
            self::$_rootId = $this->_storeManager->getStore()->getRootCategoryId();
        }

        $html = '';
        $isRoot = self::$_rootId == $collection['category_id'];

        if (!$isRoot) {
            $level++;
            $baseUrl = $this->_storeManager->getStore()->getBaseUrl();
            $url = $this->escaper->escapeHtml($baseUrl . $collection['url']);
            $padding = $collection['level'] * 30 - 30;
            $html .= '<div class="w-full pl-8 pr-2 list-none  mt-1" style="padding-left:'
                . $padding . 'px" class="tree-leaf">';
            $html .= '<a ' . $this->alpineAttrributes . 'class="text-blue-600 hover:underline" href="' . $url . '">';
            $html .= $this->escaper->escapeHtml($collection['name']);
            $html .= '</a>';
        }

        if (!empty($collection['children'])) {
            foreach ($collection['children'] as $children) {
                $html .= $this->renderTree($children, $level, $isTree);
            }
        }

        if (!$isRoot) {
            $html .= '</div>';
        }

        return $html;
    }

    public function renderArrayChunks($collection, $type, $columnSize = 1, $isTree = false)
    {
        if (!$this->currentTheme->isHyva()) {
            return parent::renderArrayChunks($collection, $type, $columnSize, $isTree);
        }

        $data = $this->_getArrayInfo($collection, $columnSize);
        $columnWidth = 100 / $columnSize;

        $html = '<div class="am-sitemap-wrap am-clearfix inline-block w-full">';
        foreach ($data['resultArray'] as $group) {
            $html .= '<div class="am-sitemap-column float-left max-sm:!w-full max-md:!w-1/2" style="width:'
                . $columnWidth . '%;">';
            $html .= '<div class="am-sitemap-cell max-sm:!pb-0">'
                . ($isTree ? '' : '<div class="am-sitemap-list max-sm:!pb-0">');

            foreach ($group as $item) {
                $html .= $this->_renderFunction($type, $item);
            }
            $html .= ($isTree ? '' : '</div>') . '</div></div>';
        }
        $html .= '</div>';

        return $html;
    }

    protected function _renderFunction($type, $item)
    {
        if (!$this->currentTheme->isHyva()) {
            return parent::_renderFunction($type, $item);
        }

        if ($type == 'categories_tree') {
            return $this->renderTree($item);
        }

        if ($type == 'product_split') {
            $html = '<dl><dt class="font-bold">' . $item['letter'] . '</dt><dd><div>';
            foreach ($item['items'] as $product) {
                $html .= $this->_renderFunction('product', $product);
            }
            $html .= '</div></dd></dl>';
            return $html;
        }

        $url = '';
        $name = '';

        switch ($type) {
            case 'product':
                $url = $item->getProductUrl();
                $name = $item->getName();
                break;
            case 'categories_list':
                $url = $item->getUrl();
                $name = $item->getName();
                break;
            case 'pages':
            case 'links':
            case 'landing_pages':
                $url = $item['url'];
                $name = $item['title'];
                break;
            default:
                break;
        }

        return $this->renderHref($url, $name);
    }

    private function renderHref($url, $name)
    {
        return "<div class='w-full pl-8 pr-2 list-none mt-1'><a " .
            $this->alpineAttrributes .
            " class='text-blue-600 hover:underline' href='" .
            $this->escaper->escapeHtml($url) . "'>" .
            $this->escaper->escapeHtml($name) .
            "</a></div>";
    }
}
